@@ -231,12 +231,15 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
     # Right now, PUMAs are not defined for 2020 and are not in the CB file
     # Use the 2019 CB pumas for 2020 and 2021 as they align with the boundaries
-    # used; 2022 should switch to the new 2020 PUMA boundaries (which aren't
-    # yet available)
+    # used; 2022 should switch to the new 2020 PUMA boundaries which are available       in the 2020 CB file
     if (year %in% 2020:2021) {
       if (cb) {
         year <- 2019
       }
+    } else if (year >= 2022) {
+      if (cb) {
+        year <- 2020
+      }
     }
 
     state_ids <- c("AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DE", "FL", "GA",
@@ -251,15 +254,26 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
       }) %>%
         rbind_tigris()
     } else if (is.null(state)) {
-      pm <- purrr::map(state_ids, function(x) {
-        pumas(state = x, cb = cb, year = year, class = "sf", ...)
-      }) %>%
-        rbind_tigris()
+
+      if (!year %in% 2019:2020 && !cb) {
+        pm <- purrr::map(state_ids, function(x) {
+          pumas(state = x, cb = cb, year = year, class = "sf", ...)
+        }) %>%
+          rbind_tigris()
+      } else {
+        pm <- pumas(state = state, cb = cb, year = year, class = "sf", ...)
+      }
     } else {
       pm <- pumas(state = state, cb = cb, year = year, class = "sf", ...)
     }
 
-    pm <- rename(pm, GEOID = GEOID10)
+    if ("GEOID20" %in% names(pm)) {
+      pm <- rename(pm, GEOID = GEOID20)
+    } else {
+      pm <- rename(pm, GEOID = GEOID10)
+    }
+
+
 
     return(pm)
 
@@ -588,7 +602,7 @@ variables_from_table_decennial <- function(table, year, sumfile, cache_table) {
 
   # Find all variables that match the table
 
-  if (year == 2020 && sumfile %in% c("pl", "dhc", "dp")) {
+  if (year == 2020 && sumfile %in% c("pl", "dhc", "dp", "ddhca")) {
     vars <- df %>%
       filter(grepl(paste0(table, "_[0-9]+"), name)) %>%
       pull(name)
@@ -647,9 +661,9 @@ summary_files <- function(year) {
                   "gu", "vi", "cd113", "cd113profile",
                   "cd115", "cd115profile", "cd116")
   } else if (year == 2020) {
-    sumfiles <- c("pl", "dhc", "dp", "pes", "dpas",
+    sumfiles <- c("pl", "dhc", "dp", "pes", "dpas", "ddhca",
                   "dpmp", "dpgu", "dpvi",
-                  "dhcvi", "dhcgu", "dhcvi", "dhcas")
+                  "dhcvi", "dhcgu", "dhcvi", "dhcas", "cd118")
   } else {
     stop("Invalid year for `get_decennial()`; valid years are 2000, 2010, and 2020.", call. = FALSE)
   }
